@@ -1,5 +1,6 @@
 package RemoteTestApp1;
-
+use strict;
+use warnings;
 use Catalyst qw/
    Authentication
 /;
@@ -25,21 +26,7 @@ __PACKAGE__->config(
     },
 );
 
-sub default : Local {
-    my ( $self, $c ) = @_;
-    if ($c->authenticate()) {
-        $c->res->body('User:' . $c->user->{username});
-    }
-    else {
-        $c->res->body('FAIL');
-        $c->res->status(403);
-    }
-}
-
-sub public : Local {
-    my ( $self, $c ) = @_;
-    $c->res->body('OK');
-}
-
 __PACKAGE__->setup;
 
+1;
+
